Skip to main content Skip to main content
Pigweed's logo Pigweed
  1. Home
  2. Reference
  3. Rust
  4. pw_log
  5. debugf

debugf

Macro debugf 

macro_rules! debugf {
    ($($args:expr),* $(,)?) => { ... };
}
Emit a debug level log message using printf format string semantics.

use pw_log::debugf;

debugf!("Log Fact: The American toy Lincoln Logs were inspired by the %s in %s.",
    "Imperial Hotel", "Tokyo");